@@ -88,7 +88,7 @@ class _cb_container(object):
                 if m1 is not m2:
                     self._getobj(m1)._fwd_cbs[id(m2)] = m2
 
-    def add_temporary_artist(self, artist, layer=None):
+    def add_temporary_artist(self, artist):
         """
         make an artist temporary
         (e.g. remove it from the map at the next event)
@@ -97,12 +97,8 @@ class _cb_container(object):
         ----------
         artist : matplotlib.artist
             the artist to use
-        layer : int, optional
-            the layer to put the artist on. The default is None.
         """
-        if layer is None:
-            layer = self._m.layer
-        self._m.BM.add_artist(artist, layer=layer)
+        self._m.BM.add_artist(artist)
         self._temporary_artists.append(artist)
 
 
@@ -404,8 +400,10 @@ class _click_container(_cb_container):
         # if multiple assignments are properly handled
         multi_cb_functions = ["mark", "annotate"]
 
-        if double_click:
+        if double_click is True:
             btn_key = "double"
+        elif double_click == "release":
+            btn_key = "release"
         else:
             btn_key = "single"
 
@@ -454,6 +452,7 @@ class cb_click_container(_click_container):
         super().__init__(*args, **kwargs)
 
         self._cid_button_press_event = None
+        self._cid_button_release_event = None
         self._cid_motion_event = None
         self._only = []
 
@@ -488,6 +487,14 @@ class cb_click_container(_click_container):
                 ):
                     cb(**clickdict)
 
+    def _onrelease(self, event):
+        cbs = self.get.cbs["release"]
+
+        if event.button in cbs:
+            bcbs = cbs[event.button]
+            for cb in bcbs.values():
+                cb()
+
     def _reset_cids(self):
         self._cid_button_press_event = None
         self._cid_motion_event = None
@@ -497,7 +504,7 @@ class cb_click_container(_click_container):
             self._event = event
 
             # ignore callbacks while dragging axes
-            if self._m._draggable_axes._modifier_pressed:
+            if self._m._ignore_cb_events:
                 return
             # don't execute callbacks if a toolbar-action is active
             if (
@@ -519,7 +526,7 @@ class cb_click_container(_click_container):
             self._event = event
 
             # ignore callbacks while dragging axes
-            if self._m._draggable_axes._modifier_pressed:
+            if self._m._ignore_cb_events:
                 return
             # don't execute callbacks if a toolbar-action is active
             if (
@@ -542,11 +549,37 @@ class cb_click_container(_click_container):
 
             self._m.parent.BM.update(clear=self._method)
 
+        def releasecb(event):
+            # ignore callbacks while dragging axes
+            if self._m._ignore_cb_events:
+                return
+            # don't execute callbacks if a toolbar-action is active
+            if (
+                self._m.figure.f.canvas.toolbar is not None
+            ) and self._m.figure.f.canvas.toolbar.mode != "":
+                return
+
+            # execute onclick on the maps object that belongs to the clicked axis
+            # and forward the event to all forwarded maps-objects
+            for obj in self._objs:
+                obj._onrelease(event)
+                # forward callbacks to the connected maps-objects
+                obj._fwd_cb(event)
+
+            # self._m.parent.BM.update(clear=False)
+
         if self._cid_button_press_event is None:
             # ------------- add a callback
             self._cid_button_press_event = self._m.figure.f.canvas.mpl_connect(
                 "button_press_event", clickcb
             )
+
+        if self._cid_button_release_event is None:
+            # ------------- add a callback
+            self._cid_button_release_event = self._m.figure.f.canvas.mpl_connect(
+                "button_release_event", releasecb
+            )
+
         if self._cid_motion_event is None:
             # for click-callbacks, allow motion-detection
             self._cid_motion_event = self._m.figure.f.canvas.mpl_connect(
@@ -558,42 +591,42 @@ class cb_click_container(_click_container):
         if event.inaxes != self._m.figure.ax:
             return
 
-        for key, m in self._fwd_cbs.items():
-            obj = self._getobj(m)
-            if obj is None:
-                continue
+        if event.name == "button_release_event":
+            for key, m in self._fwd_cbs.items():
+                obj = self._getobj(m)
+                if obj is None:
+                    continue
+                obj._onrelease(event)
 
-            transformer = Transformer.from_crs(
-                self._m.crs_plot,
-                m.crs_plot,
-                always_xy=True,
-            )
+        else:
+            for key, m in self._fwd_cbs.items():
+                obj = self._getobj(m)
+                if obj is None:
+                    continue
 
-            # transform the coordinates of the clicked location
-            xdata, ydata = transformer.transform(event.xdata, event.ydata)
+                transformer = Transformer.from_crs(
+                    self._m.crs_plot,
+                    m.crs_plot,
+                    always_xy=True,
+                )
 
-            dummyevent = SimpleNamespace(
-                inaxes=m.figure.ax,
-                dblclick=event.dblclick,
-                button=event.button,
-                xdata=xdata,
-                ydata=ydata,
-            )
+                # transform the coordinates of the clicked location
+                xdata, ydata = transformer.transform(event.xdata, event.ydata)
 
-            dummymouseevent = SimpleNamespace(
-                inaxes=m.figure.ax,
-                dblclick=event.dblclick,
-                button=event.button,
-                xdata=xdata,
-                ydata=ydata,
-                # x=event.mouseevent.x,
-                # y=event.mouseevent.y,
-            )
+                dummymouseevent = SimpleNamespace(
+                    inaxes=m.figure.ax,
+                    dblclick=event.dblclick,
+                    button=event.button,
+                    xdata=xdata,
+                    ydata=ydata,
+                    # x=event.mouseevent.x,
+                    # y=event.mouseevent.y,
+                )
 
-            obj._onclick(dummymouseevent)
-            # append clear-action again since it will already be executed
-            # by the first click!
-            m.BM._after_update_actions.append(obj._clear_temporary_artists)
+                obj._onclick(dummymouseevent)
+                # append clear-action again since it will already be executed
+                # by the first click!
+                m.BM._after_update_actions.append(obj._clear_temporary_artists)
 
 
 class cb_pick_container(_click_container):
@@ -661,6 +694,9 @@ class cb_pick_container(_click_container):
         self._add_pick_callback()
 
     def _default_picker(self, artist, event):
+        # if no pick-callback is attached, don't identify the picked point
+        if len(self._m.cb.pick.get.cbs) == 0:
+            return False, None
 
         if (event.inaxes != self._m.ax) or not hasattr(self._m, "tree"):
             return False, dict(ind=None, dblclick=event.dblclick, button=event.button)
@@ -737,21 +773,22 @@ class cb_pick_container(_click_container):
         # execute onpick and forward the event to all connected Maps-objects
 
         def pickcb(event):
-            if not self._artist is event.artist:
+            # check if we want to ignore callbacks
+            if self._m._ignore_cb_events:
                 return
 
-            self._event = event
-            # check if the artists has a custom picker assigned
-
-            # ignore callbacks while dragging axes
-            if self._m._draggable_axes._modifier_pressed:
-                return
             # don't execute callbacks if a toolbar-action is active
             if (
                 self._m.figure.f.canvas.toolbar is not None
             ) and self._m.figure.f.canvas.toolbar.mode != "":
                 return
 
+            if not self._artist is event.artist:
+                return
+
+            self._event = event
+            # check if the artists has a custom picker assigned
+
             # execute "_onpick" on the maps-object that belongs to the clicked axes
             # and forward the event to all forwarded maps-objects
             self._onpick(event)
